import logging
from typing import List

from fastapi import APIRouter

from example_template_service.metrics import metrics
from example_template_service.service import DlExampleService
from example_template_service.utils import initialize_configuration

logger = logging.getLogger(__name__)


__all__ = ('example_service_router',)

service: DlExampleService


def on_startup() -> None:
    """Lazy loading of the service to avoid loading models too soon."""
    global service
    config = initialize_configuration()
    service = DlExampleService(config=config)


example_service_router = APIRouter()
example_service_router.add_event_handler('startup', on_startup)


@example_service_router.post('/example/sum', tags=['sum'])
async def addition(inputs: List[float]):

    logger.info(f'Received addition request (service)')
    metrics.called('/example/sum')
    try:
        response = service.add(data=inputs)
    except Exception:
        metrics.call_failed('/example/sum')
        raise

    logger.debug(f"Returning response {response}")

    return response


@example_service_router.get('/example/version', tags=['version'])
async def addition():

    logger.info(f'Received addition request (service)')
    metrics.called('/example/version')
    try:
        response = service.version()
    except Exception:
        metrics.call_failed('/example/version')
        raise

    logger.debug(f"Returning response {response}")

    return response



import logging
import os

import prometheus_client as prometheus
from example_template_foundation.configuration_manager import (
    ConfigurationManager,
)

from example_template_service.constants import (
    DEFAULT_CONFIG_PATH,
    DEFAULT_PROMETHEUS_ENABLED,
    DEFAULT_PROMETHEUS_PORT,
)

logger = logging.getLogger(__name__)

__all__ = (
    'initialize_configuration',
    'initialize_prometheus',
)


def initialize_configuration() -> ConfigurationManager:
    config_path = os.getenv('REMOTE_CONFIG_URL', DEFAULT_CONFIG_PATH)
    return ConfigurationManager.from_path(config_path)


def initialize_prometheus(config: ConfigurationManager) -> None:
    if config.get('prometheus.enabled', DEFAULT_PROMETHEUS_ENABLED):
        prometheus_port = config.get('prometheus.port', DEFAULT_PROMETHEUS_PORT)
        logger.info(f'Starting prometheus client on port {prometheus_port}')
        prometheus.start_http_server(prometheus_port)
    else:
        logger.info('Prometheus client is not configured.')



DEFAULT_CONFIG_PATH = '/etc/example-template-service/config.yml'
DEFAULT_SERVICE_PORT = 5000
DEFAULT_PROMETHEUS_PORT = 8080
DEFAULT_PROMETHEUS_ENABLED = True
DEFAULT_SILENCE_KLEIN_LOGS = True
DEFAULT_MAX_WORKERS = 4
DEFAULT_LOG_LEVEL = 'info'
DEFAULT_HOST = '0.0.0.0'
PROJECT_NAME = 'example-template-service'
PROJECT_DESCRIPTION = 'Example service of the Media Distillery Service Template'
API_VERSION_PREFIX = '/api/1'



# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['example_template_service', 'example_template_service.api_v1']

package_data = \
{'': ['*']}

install_requires = \
['example-template-core==0.1.0',
 'example-template-foundation==1.0.0',
 'fastapi>=0.63.0,<0.64.0',
 'prometheus-client>=0.6.0',
 'pydantic>=1.7.3,<1.8.0',
 'python-multipart>=0.0.5,<0.0.6',
 'uvicorn>=0.13.3,<0.14.0']

entry_points = \
{'console_scripts': ['example_template_service_web_start = '
                     'example_template_service.run:run_cli',
                     'run-cli = example_template_service.run:run_cli']}

setup_kwargs = {
    'name': 'example-template-service',
    'version': '1.0.0',
    'description': '',
    'long_description': None,
    'author': 'Anustup Das',
    'author_email': 'anustup@mediadistillery.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)



import logging

from example_template_core.utils import check_number_input
from example_template_foundation.configuration_manager import (
    ConfigurationManager,
    ConfigurationMixin,
)

from example_template_service.constants import *
from example_template_service.version import __version__

logger = logging.getLogger(__name__)

__all__ = ('DlExampleService',)


class DlExampleService(ConfigurationMixin):
    def __init__(self, config: ConfigurationManager = None) -> None:
        self.load_config(config=config, default_location=DEFAULT_CONFIG_PATH)

    def add(self, data) -> float:
        sum = 0
        print(data)
        print(f"We have {check_number_input(data)} numbers to add")
        for i in data:
            sum += i
            print(sum)

        print(f"Version of the service: {__version__}")
        return sum

    def version(self) -> float:
        print(f"Version of the service: {__version__}")
        v = __version__
        return v
